@@ -29,7 +29,7 @@ class AccessTokenClient(BaseClient):
         """
         global cache
 
-        cache_key = self.get_cache_key()
+        cache_key = self._get_cache_key()
         try:
             access_token = cache[cache_key]
             logger.debug('from cache')
@@ -54,7 +54,7 @@ class AccessTokenClient(BaseClient):
         :return:
         """
         global grantless_cache
-        cache_key = self.get_cache_key()
+        cache_key = self._get_cache_key()
         try:
             access_token = grantless_cache[cache_key]
             logger.debug('from_cache')
@@ -92,5 +92,5 @@ class AccessTokenClient(BaseClient):
             'content-type': self.content_type
         }
 
-    def get_cache_key(self):
+    def _get_cache_key(self):
         return 'access_token_' + hashlib.md5(self.credentials.refresh_token.encode('utf-8')).hexdigest()
